# Data apps for Jupyter and Production

Solara is the bridge between Jupyter-based data-app development and production deployment.

## What is Solara?

Solara lets you use and build data-focused web apps (data apps) using reusable UI components. Your app will work in the Jupyter notebook and production-grade web frameworks (FastAPI, Starlette, Flask, ...).

Solara uses proven technologies and mature standards. Grow from a one-off experiment in the Jupyter notebook or a dynamic data portal in production.  Built on top of React-IPywidgets keeps your code complexity under control.

We care about developer experience. Solara will give your hot code reloading and type hints to faster development.

[![Introduction](https://dabuttonfactory.com/button.png?t=Introduction&f=Open+Sans-Bold&ts=20&tc=fff&hp=45&vp=12&c=8&bgt=unicolored&bgc=f19f41)](/docs)
[![Guides](https://dabuttonfactory.com/button.png?t=Guides&f=Open+Sans-Bold&ts=20&tc=fff&hp=45&vp=12&c=8&bgt=unicolored&bgc=f19f41)](/docs/guides)
<!-- [![Book a demo](https://dabuttonfactory.com/button.png?t=Book+a+demo&f=Open+Sans-Bold&ts=20&tc=f19f41&hp=45&vp=12&c=8&bgt=unicolored&bgc=eee&bs=1&bc=f19f41)](/docs/guides) -->
